@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2005-2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2005-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -131,6 +130,7 @@ FFmpegStream::FFmpegStream(IManageDemuxPacket* demuxPacketManager, const Propert
 FFmpegStream::FFmpegStream(IManageDemuxPacket* demuxPacketManager, const Properties& props, std::shared_ptr<CurlInput> curlInput, const HttpProxy& httpProxy)
   : BaseStream(demuxPacketManager),
     m_openMode(props.m_openMode),
+    m_streamMode(props.m_streamMode),
     m_manifestType(props.m_manifestType),
     m_curlInput(curlInput),
     m_httpProxy(httpProxy),
@@ -792,14 +792,9 @@ bool FFmpegStream::Open(bool fileinfo)
 
   // select the correct program if requested
   m_initialProgramNumber = UINT_MAX;
-  CVariant programProp;
-  if (!m_programProperty.empty())
-  {
-    CVariant programProp(m_programProperty);
-
-    if (!programProp.isNull() && programProp.isInteger())
-      m_initialProgramNumber = static_cast<int>(programProp.asInteger());
-  }
+  CVariant programProp(m_programProperty.empty() ? CVariant::VariantTypeNull : CVariant(m_programProperty));
+  if (!programProp.isNull())
+    m_initialProgramNumber = static_cast<int>(programProp.asInteger());
 
   // in case of mpegts and we have not seen pat/pmt, defer creation of streams
   if (!skipCreateStreams || m_pFormatContext->nb_programs > 0)
@@ -841,6 +836,11 @@ bool FFmpegStream::Open(bool fileinfo)
             }
           }
         }
+
+        // We appear to need this hack for catchup, not sure why and can't be arsed trying to find out
+        // Without it a seek is interpreted as a program change and the stream will stall infinitely.
+        if (m_streamMode == StreamMode::CATCHUP && m_initialProgramNumber == UINT_MAX)
+          m_initialProgramNumber = 0;
       }
     }
     CreateStreams(nProgram);
