@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2005-2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2005-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -195,6 +194,7 @@ private:
 
   HttpProxy m_httpProxy;
   OpenMode m_openMode;
+  StreamMode m_streamMode;
 };
 
 } //namespace ffmpegdirect
